aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal
diff options
context:
space:
mode:
authorRocco Marco Guglielmi <roccomarco.guglielmi@live.com>2016-06-02 13:10:18 +0000
committerRocco Marco Guglielmi <roccomarco.guglielmi@live.com>2016-06-02 13:10:18 +0000
commitcd7b086b12fa9af6bdeacfaa91e9ad94f411a6be (patch)
tree8ff2486f708a6844d885c64d7da3891003a63a85 /os/hal
parentffd47e9af73a9e4a27e1747589085bd2b9f9557a (diff)
downloadChibiOS-cd7b086b12fa9af6bdeacfaa91e9ad94f411a6be.tar.gz
ChibiOS-cd7b086b12fa9af6bdeacfaa91e9ad94f411a6be.tar.bz2
ChibiOS-cd7b086b12fa9af6bdeacfaa91e9ad94f411a6be.zip
Small indent fixes
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@9554 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/hal')
-rw-r--r--os/hal/lib/peripherals/sensors/hal_sensors.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/os/hal/lib/peripherals/sensors/hal_sensors.h b/os/hal/lib/peripherals/sensors/hal_sensors.h
index db8d10269..fc9268224 100644
--- a/os/hal/lib/peripherals/sensors/hal_sensors.h
+++ b/os/hal/lib/peripherals/sensors/hal_sensors.h
@@ -45,8 +45,8 @@
* @brief BaseSensor specific methods.
*/
#define _base_sensor_methods_alone \
- /* Get number of axes.*/ \
- size_t (*get_axes_number)(void *instance); \
+ /* Get number of channels.*/ \
+ size_t (*get_channels_number)(void *instance); \
/* Reads the sensor raw data.*/ \
msg_t (*read_raw)(void *instance, int32_t axes[]); \
/* Reads the sensor returning normalized data.*/ \
@@ -92,14 +92,14 @@ typedef struct {
* @{
*/
/**
* @brief Sensors get axes number.
*
* @param[in] ip pointer to a @p BaseSensor or derived class.
* @return The number of axes of the BaseSensor
*
* @api
*/
-#define sensorGetAxesNumber(ip) (ip)->vmt_basesensor->get_axes_number(ip)
+#define sensorGetChannelNumber(ip) (ip)->vmt_basesensor->get_channels_number(ip)
/**
* @brief Sensors read raw data.
@@ -92,14 +92,14 @@ typedef struct {
*/
/**
- * @brief Sensors get axes number.
+ * @brief Sensors get channels number.
*
* @param[in] ip pointer to a @p BaseSensor or derived class.
@@ -92,14 +92,14 @@ typedef struct {
*
* @param[in] ip pointer to a @p BaseSensor or derived class.
- * @return The number of axes of the BaseSensor
+ * @return The number of channels of the BaseSensor
*
* @api